#
# spec file for package perl-File-Tail
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-Tail
Name:           perl-File-Tail
Version:        1.300.0
Release:        1.2
# 1.3 -> normalize -> 1.300.0
%define cpan_version 1.3
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Perl extension for reading from continously updated files
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MG/MGRABNAR/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
Provides:       perl(File::Tail) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
The primary purpose of File::Tail is reading and analysing log files while
they are being written, which is especialy usefull if you are monitoring
the logging process with a tool like Tobias Oetiker's MRTG.

The module tries very hard NOT to "busy-wait" on a file that has little
traffic. Any time it reads new data from the file, it counts the number of
new lines, and divides that number by the time that passed since data were
last written to the file before that. That is considered the average time
before new data will be written. When there is no new data to read,
'File::Tail' sleeps for that number of seconds. Thereafter, the waiting
time is recomputed dynamicaly. Note that 'File::Tail' never sleeps for more
than the number of seconds set by 'maxinterval'.

If the file does not get altered for a while, 'File::Tail' gets suspicious
and startschecking if the file was truncated, or moved and recreated. If
anything like that had happened, 'File::Tail' will quietly reopen the file,
and continue reading. The only way to affect what happens on reopen is by
setting the reset_tail parameter (see below). The effect of this is that
the scripts need not be aware when the logfiles were rotated, they will
just quietly work on.

Note that the sleep and time used are from Time::HiRes, so this module
should do the right thing even if the time to sleep is less than one
second.

The logwatch script (also included) demonstrates several ways of calling
the methods.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes logwatch README select_demo Tail.pm.debug

%changelog
* Thu Feb  6 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Aug  3 2015 coolo@suse.com
- updated to 1.3
  see /usr/share/doc/packages/perl-File-Tail/Changes
  1.3     Fix for a stupid bug in 1.2 (GFILATOV, Slaven_Rezic)
    Added a warning for use of debug in a non-debug version of File::Tail
    Shows a warning when maxbuf is set to a too-small value
    Invoking name_changes callback changes the value of input attribute (sottile@ix.netcom.com)
    When deciding to reopen the file, check if the inode matches (that would mean it has not
    been ranamed)
* Wed Apr 22 2015 coolo@suse.com
- updated to 1.2
  see /usr/share/doc/packages/perl-File-Tail/Changes
  1.2     Break the infinite loop that can result when the average length of lines
    causes the attempt to fill the tail buffer to fill with the exact same
    or even smaller number of lines.
* Sun Apr 19 2015 coolo@suse.com
- updated to 1.1
  see /usr/share/doc/packages/perl-File-Tail/Changes
* Fri Feb  6 2015 coolo@suse.com
- updated to 1.0
  * Actually just two minor bug fixes (one of them in a test), but I no
    longer see a point in not having a 1.0 version.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct 19 2010 coolo@novell.com
- add perl as explicit buildrequire
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Nov 24 2005 mc@suse.de
- update to version 0.99.3
* Sun Jul 31 2005 cthiel@suse.de
- update to version 0.99.1
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Mon Jul 21 2003 mc@suse.de
- removed auto directory from file list
* Fri Jul 18 2003 mc@suse.de
- add make test
- add vendorarch changes
* Sun Jun 22 2003 coolo@suse.de
- package directories
* Mon May 19 2003 mc@suse.de
- removed unpackaged Files from RPM_BUILD_ROOT
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jul 29 2002 mls@suse.de
- fix neededforbuild for perl-5.8.0
* Tue Jul  9 2002 mc@suse.de
- initial release 0.98
